========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/renderspec.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

renderspec
==========

renderspec is a tool to convert a .spec.j2 Jinja2 template to
a rpm .spec file which is usable for different distributions
and follow their policies and processes.

Documentation for renderspec can be found at

   http://docs.openstack.org/developer/renderspec/

For more information about the OpenStack rpm packaging initiative, please
follow the link to the wiki page:

   https://wiki.openstack.org/wiki/Rpm-packaging

In the unfortunate event that bugs are discovered, they should
be reported to the appropriate bug tracker. If you obtained
the software from a 3rd party operating system vendor, it is
often wise to use their own bug tracker for reporting problems.
In all other cases use the master OpenStack bug tracker,
available at:

   https://bugs.launchpad.net/renderspec

Developers wishing to work on renderspec should always base
their work on the latest code, available from the master GIT
repository at:

   https://git.openstack.org/cgit/openstack/renderspec

Developers should also join the discussion on the mailing list,
at:

   http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev

or join the IRC channel on

   http://webchat.freenode.net/?channels=openstack-rpm-packaging
